/*
Required input files:	
	mortality_data.dta
	SEER_data.dta
	BEA_data.dta

Output files:
	table_1.csv
	table_mort_main_raw.csv
	figure_mort_main_raw.csv
*/

*****************************
* Initialization
*****************************

* Set this local equal to the folder location for this script, e.g., "C:/Users/name/myfolder/"
local workdir ""

clear
set more off
tempfile main_data mort_tmp1 mort_tmp2 phy_tmp

* Set the flag equal to 1 to run that analysis, and equal to 0 otherwise
* Note: mortality analysis cannot be run without first obtaining access to the vital statistics data 
local table_1 = 0
local table_mort_main = 0
local figure_mort_main = 0

*****************************
* Set up data for mortality analysis
*****************************

* Obtain population data
use "`workdir'data/SEER_data.dta", clear

* Aggregate total population by state and year
sort staters year
bysort staters year: egen pop_styr=sum(yearlypop)

* Add time-varying state variables
merge m:1 staters year using "`workdir'data/BEA_data.dta"
drop _merge

replace medical=medical/pop_styr
replace employment=employment/pop_styr
keep staters year sex age race yearlypop medical employment pcincome healthcare

* Merge on multiple cause-of-death data
merge 1:m staters year sex age race using "`workdir'data/mortality_data.dta"
drop if _merge==2 & age!=9999
replace yearlydeaths=0 if _merge==1
drop _merge

compress
save "`main_data'", replace

*****************************
* Table 1
*****************************

if `table_1'==1 {

	* Average total deaths by cause-of-death for 65 and over, 2001-2008
	use "`workdir'data/mortality_data.dta", clear
	drop if year<2001|year>2008
	drop if age<65

	* Re-define specific cause-of-death for the table
	gen category=" "
	replace category="a01 Heart Failure" if heartfailure==1	
	replace category="a02 Ischemic and Hypertension" if hypertension==1|ischemic==1|myocardial==1
	replace category="a03 Other Heart" if cause==10&heartfailure!=1&hypertension!=1&ischemic!=1&myocardial!=1
	replace category="a04 Cerebrovascular (Stroke)" if cause==12
	replace category="a05 Peripheral Vascular" if pvd==1
	replace category="a06 Other CVD" if cause==9&hypertension!=1&pvd!=1
	replace category="b01 Digestive" if cause==2
	replace category="b02 Lung" if cause==3
	replace category="b03 Breast" if cause==4
	replace category="b04 Genital" if cause==5
	replace category="b05 Lymph" if cause==6
	replace category="b06 Bladder" if bladd==1
	replace category="b07 Thyroid" if thyroid==1
	replace category="b08 Other Cancer" if cause==1&bladd!=1&thyroid!=1
	replace category="c01 Diabetes" if cause==7
	replace category="c02 Alzheimer's" if cause==8
	replace category="c03 Chronic Lower Respiratory" if cause==13
	replace category="c04 Renal Failure" if renalfailure==1
	replace category="c05 Other Kidney" if cause==15&renalfailure!=1
	replace category="c06 Upper Respiratory" if urd==1
	replace category="c07 Respiratory Failure" if respfailure==1
	replace category="c08 Lipid Metabolism" if lipidmeta==1
	replace category="c09 Digestive System" if cause==14|odigest==1
	replace category="c10 Parkinson's" if parkins==1
	replace category="c11 Pneumonia" if pneum==1
	replace category="c12 Other" if cause==0&lipidmeta!=1&urd!=1&respfailure!=1&odigest!=1&parkins!=1&pneum!=1
	replace category="d01 Transport Accidents" if cause==18
	replace category="d02 Falls" if cause==19
	replace category="d03 Drowning/Submersion" if cause==20
	replace category="d04 Smoke/Fires/Flame" if cause==21	
	replace category="d05 Poison/Noxious Substance" if cause==22
	replace category="d06 Other Accidents" if cause==17
	replace category="d07 Suicide" if cause==23
	replace category="d08 Homicide" if cause==24
	replace category="d09 Other External Causes" if cause==16
	
	collapse (sum) yearlydeaths, by(category) fast
	
	gen avgdeaths=yearlydeaths/8
	drop yearlydeaths
	
	* Export to create table
	outsheet category avgdeaths using "`workdir'results/table_1.csv", comma replace

}

*****************************
* Tables 3, 4, 9, 10, 11, 12, 13, 14, 15
*****************************

if `table_mort_main'==1 {
	
	local replace "replace"
	
	* Mortality analysis
	* Race: 1=white, 2=non-white, 3=all
	* Gender: 1=male, 2=female, 3=all
	* Time window: 4051=2001-2008, 3051=2002-2007, 8051=1997-2012
	* Physician density: 1=below median, 2=above median, 3=all
	foreach race in "1" "2" "3" {
	foreach gender in "1" "2" "3" {
	foreach timewindow in "4051" "3051" "8051" {
	foreach phymedian in "1" "2" "3" {
	foreach ageband in "6466" "6465" "6166" "6167" "6168" "6169" "6266" "6267" "6268" "6269" "6366" "6367" "6368" "6369" "6467" "6468" "6469" "6162" "6163" "6164" "6263" "6264" "6364" {
		foreach cause in "any_cause" "cardiovascular" "cancer" "other" {
			
			* Skip combinations that are not used in the paper
			if !inlist(`ageband', 6466, 6465, 6162, 6163, 6164, 6263, 6264, 6364) {
				if `race'!=3|`gender'!=3|`timewindow'!=4051|`phymedian'!=3 continue, break
			}
			if inlist(`ageband', 6465, 6162, 6163, 6164, 6263, 6264, 6364) {
				if `timewindow'!=4051|`phymedian'!=3 continue, break
			}
			if `phymedian'!=3 {
				if `race'!=3|`gender'!=3|`timewindow'!=4051 continue, break
			}
			if `race'!=3 & `gender'!=3 continue, break
									
			use "`main_data'", clear
			
			* By gender
			if `gender'==1 {
			keep if sex==1
			}
			if `gender'==2 {
			keep if sex==2
			}

			* By race
			if `race'==1 {
			keep if race==1
			}
			if `race'==2 {
			keep if race!=1
			}	
		
			* Define time windows					
			if `timewindow'==4051 {
			keep if year>=2001 & year<=2008
			gen postpartd=0
			replace postpartd=1 if (year>=2005 & year<=2008)
			}
			if `timewindow'==3051 {
			keep if year>=2002 & year<=2007
			gen postpartd=0
			replace postpartd=1 if (year>=2005 & year<=2007)
			}
			if `timewindow'==8051 {
			keep if year>=1997 & year<=2012
			gen postpartd=0
			replace postpartd=1 if (year>=2005 & year<=2012)
			}						
										
			* Categorize specific causes of death
			gen any_cause=1
			gen cardiovascular=0
			replace cardiovascular=1 if cause>=9 & cause<=12
			gen cancer=0
			replace cancer=1 if cause>=1 & cause<=6
			gen other=0
			replace other=1 if cause==0|cause==7|cause==8|cause==13|cause==14|cause==15
			gen ischemic_combined=0
			replace ischemic_combined=1 if ischemic==1|cause==11
			gen cardio_excl_hischm=0
			replace cardio_excl_hischm=1 if hypertension==0 & ischemic_combined==0 & cause>=9 & cause<=12
			gen ischypers=0
			replace ischypers=1 if (ischemic==1|cause==11) | hypertension==1
			gen other_sig=0
			replace other_sig=1 if (other==1&cause!=15&respfailure!=1&parkins!=1&pneum!=1)		
			gen other_nosig=0
			replace other_nosig=1 if (other==1&other_sig!=1)	
			gen external =(cause>=16 & cause<=24)
			replace yearlydeaths=0 if `cause'!=1
			
      		save `phy_tmp', replace
        
       		* Generate terciles of physicians per capita, 2003
			keep if year==2003
			duplicates drop staters year sex age race, force
			bysort staters: egen pop2003=sum(yearlypop)
			duplicates drop staters, force
			replace phys03_nf_pc= phys03_nf_pc/pop2003
			xtile tcile = phys03_nf_pc, nq(2)
			
			keep staters tcile
		
			merge 1:m staters using `phy_tmp'
			drop _merge
		
			* Define young elderly and near elderly
			if `ageband'==6466 {
			gen elderly=1
			replace elderly=0 if age==64
			drop if elderly!=0 & age!=66
			}
			if `ageband'==6465 {
			gen elderly=1
			replace elderly=0 if age==64
			drop if elderly!=0 & age!=65
			}			
			if `ageband'==6166 {
			gen elderly=1
			replace elderly=0 if age==61
			drop if elderly!=0 & age!=66
			}
			if `ageband'==6167 {
			gen elderly=1
			replace elderly=0 if age==61
			drop if elderly!=0 & age!=67
			}			
			if `ageband'==6168 {
			gen elderly=1
			replace elderly=0 if age==61
			drop if elderly!=0 & age!=68
			}
			if `ageband'==6169 {
			gen elderly=1
			replace elderly=0 if age==61
			drop if elderly!=0 & age!=69
			}
			if `ageband'==6266 {
			gen elderly=1
			replace elderly=0 if age==62
			drop if elderly!=0 & age!=66
			}
			if `ageband'==6267 {
			gen elderly=1
			replace elderly=0 if age==62
			drop if elderly!=0 & age!=67
			}			
			if `ageband'==6268 {
			gen elderly=1
			replace elderly=0 if age==62
			drop if elderly!=0 & age!=68
			}
			if `ageband'==6269 {
			gen elderly=1
			replace elderly=0 if age==62
			drop if elderly!=0 & age!=69
			}
			if `ageband'==6366 {
			gen elderly=1
			replace elderly=0 if age==63
			drop if elderly!=0 & age!=66
			}
			if `ageband'==6367 {
			gen elderly=1
			replace elderly=0 if age==63
			drop if elderly!=0 & age!=67
			}			
			if `ageband'==6368 {
			gen elderly=1
			replace elderly=0 if age==63
			drop if elderly!=0 & age!=68
			}
			if `ageband'==6369 {
			gen elderly=1
			replace elderly=0 if age==63
			drop if elderly!=0 & age!=69
			}
			if `ageband'==6467 {
			gen elderly=1
			replace elderly=0 if age==64
			drop if elderly!=0 & age!=67
			}			
			if `ageband'==6468 {
			gen elderly=1
			replace elderly=0 if age==64
			drop if elderly!=0 & age!=68
			}
			if `ageband'==6469 {
			gen elderly=1
			replace elderly=0 if age==64
			drop if elderly!=0 & age!=69
			}
			if `ageband'==6162 {
			gen elderly=1
			replace elderly=0 if age==61
			drop if elderly!=0 & age!=62
			}
			if `ageband'==6163 {
			gen elderly=1
			replace elderly=0 if age==61
			drop if elderly!=0 & age!=63
			}
			if `ageband'==6164 {
			gen elderly=1
			replace elderly=0 if age==61
			drop if elderly!=0 & age!=64
			}
			if `ageband'==6263 {
			gen elderly=1
			replace elderly=0 if age==62
			drop if elderly!=0 & age!=63
			}
			if `ageband'==6264 {
			gen elderly=1
			replace elderly=0 if age==62
			drop if elderly!=0 & age!=64
			}		
			if `ageband'==6364 {
			gen elderly=1
			replace elderly=0 if age==63
			drop if elderly!=0 & age!=64
			}

			* Aggregate mortality counts and population
			bysort staters year elderly: egen deaths=sum(yearlydeaths)
			duplicates drop staters year sex age race, force
			bysort staters year elderly: egen totpop=sum(yearlypop)
			bysort staters year elderly: gen seq=_n
			bysort staters year elderly: keep if _n==_N
			
			* By physician density
			if `phymedian'==1|`phymedian'==2 {	
			keep if `phymedian'== tcile
			}
			
			gen lndeaths=ln(deaths)
			gen lnpop=ln(totpop)
			
			* Death rate per 100000 population	
			gen drates=deaths/totpop*100000
				
			* Create weights
			gen weights=totpop
			
			* Run regressions
			foreach regressors in "lndeaths lnpop _IposXelder* i.elderly i.staters i.year [aw=weights]" ///
							      "lndeaths lnpop _IposXelder* i.elderly i.staters i.year pcincome employment medical healthcare [aw=weights]" ///
								  "drates _IposXelder* i.elderly i.staters i.year pcincome employment medical healthcare [aw=weights]" {							  
						  
				xi i.postpartd*elderly i.age*year i.staters*i.year
				reg `regressors', vce(cluster staters)
				regsave using "`mort_tmp1'", tstat pval ci ///
				addlabel(regressors, `regressors', phymedian, `phymedian', timewindow, `timewindow', ageband, `ageband', deathcause, `cause', gender, `gender', race, `race') `replace'
				local replace "append"
			}
			drop _all
			
		}
	}
	}
	}
	}
	}
	
* Format and outsheet results for use in PivotTable
use "`mort_tmp1'", clear
replace var = subinstr(var,"foreign:","",.)
outsheet using "`workdir'results/table_mort_main_raw.csv", comma replace

}

*****************************
* Figures 1, 2, 3, 4, 7, 8
*****************************

if `figure_mort_main'==1 {
	
	local replace "replace"
	
	* Mortality analysis event study
	* Race: 1=white, 2=non-white, 3=all
	* Gender: 1=male, 2=female, 3=all
	* Time window: 4051=2001-2008, 8051=1997-2012
	* Physician density: 1=below median, 2=above median, 3=all
	foreach race in "1" "2" "3" {
	foreach gender in "1" "2" "3" {
	foreach timewindow in "4051" "8051" {
	foreach phymedian in "1" "2" "3" {
		foreach cause in "any_cause" "cardiovascular" "cancer" "other" "external" {

			* Skip combinations that are not used in the paper			
			if `phymedian'!=3 {
				if `race'!=3|`gender'!=3|`timewindow'!=4051 continue, break
			}
			if `timewindow'!=4051 {
				if `race'!=3|`gender'!=3 continue, break
			}
			if `race'!=3 & `gender'!=3 continue, break							
			
			use "`main_data'", clear
			
			* By gender
			if `gender'==1 {
			keep if sex==1
			}
			if `gender'==2 {
			keep if sex==2
			}

			* By race
			if `race'==1 {
			keep if race==1
			}
			if `race'==2 {
			keep if race!=1
			}	
		
			* Define time windows					
			if `timewindow'==4051 {
			keep if year>=2001 & year<=2008
			gen postpartd=0
			replace postpartd=1 if (year>=2005 & year<=2008)
			}
			if `timewindow'==8051 {
			keep if year>=1997 & year<=2012
			gen postpartd=0
			replace postpartd=1 if (year>=2005 & year<=2012)
			}						
										
			* Categorize specific causes of death
			gen any_cause=1
			gen cardiovascular=0
			replace cardiovascular=1 if cause>=9 & cause<=12
			gen cancer=0
			replace cancer=1 if cause>=1 & cause<=6
			gen other=0
			replace other=1 if cause==0|cause==7|cause==8|cause==13|cause==14|cause==15
			gen ischemic_combined=0
			replace ischemic_combined=1 if ischemic==1|cause==11
			gen cardio_excl_hischm=0
			replace cardio_excl_hischm=1 if hypertension==0 & ischemic_combined==0 & cause>=9 & cause<=12
			gen ischypers=0
			replace ischypers=1 if (ischemic==1|cause==11) | hypertension==1
			gen other_sig=0
			replace other_sig=1 if (other==1&cause!=15&respfailure!=1&parkins!=1&pneum!=1)		
			gen other_nosig=0
			replace other_nosig=1 if (other==1&other_sig!=1)	
			gen external =(cause>=16 & cause<=24)
			replace yearlydeaths=0 if `cause'!=1	
						
      		save `phy_tmp', replace
        
       		* Generate terciles of physicians per capita, 2003
			keep if year==2003
			duplicates drop staters year sex age race, force
			bysort staters: egen pop2003=sum(yearlypop)
			duplicates drop staters, force
			replace phys03_nf_pc= phys03_nf_pc/pop2003
			xtile tcile = phys03_nf_pc , nq(2)
			
			keep staters tcile
		
			merge 1:m staters using `phy_tmp'
			drop _merge
		
			* Define young elderly and near elderly
			gen elderly=1
			replace elderly=0 if age==64
			drop if elderly!=0 & age!=66

			* Aggregate mortality counts and population
			bysort staters year elderly: egen deaths=sum(yearlydeaths)
			duplicates drop staters year sex age race, force
			bysort staters year elderly: egen totpop=sum(yearlypop)
			bysort staters year elderly: gen seq=_n
			bysort staters year elderly: keep if _n==_N

			* By physician density
			if `phymedian'==1|`phymedian'==2 {	
			keep if `phymedian'== tcile
			}
			
			gen lndeaths=ln(deaths)
			gen lnpop=ln(totpop)
				
			* Create weights according to Finkelstein & McKnight 2007
			gen weights=totpop
			
			* Run regressions				
			char year[omit] 2004			  
			xi: reg lndeaths lnpop i.year*elderly i.staters pcincome employment medical healthcare [aw=weights], vce(cluster staters)
			regsave using "`mort_tmp2'", tstat pval ci ///
			addlabel(phymedian, `phymedian', timewindow, `timewindow', deathcause, `cause', gender, `gender', race, `race') `replace'
			local replace "append"
			drop _all
			
		}
	}
	}
	}
	}
	
* Format and outsheet results for use in PivotTable
use "`mort_tmp2'", clear
replace var = subinstr(var,"foreign:","",.)
outsheet using "`workdir'results/figure_mort_main_raw.csv", comma replace

}
